==> jc-1.4.0.tar.gz: polyglot/util/typedump/TypeDumper.h <==
// class polyglot.util.typedump.TypeDumper

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ce9c276c03241184 polyglot_util_typedump_TypeDumper

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_typedump_TypeDumper_H_
#define _JC_polyglot_util_typedump_TypeDumper_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Long$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Date$object;
struct _jc_java_util_Map$object;
struct _jc_java_util_Set$object;
struct _jc_polyglot_types_Type$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_util_CodeWriter$object;
struct _jc_polyglot_util_typedump_TypeDumper$object;

// Typedefs
typedef struct _jc_polyglot_util_typedump_TypeDumper$sub_refs	_jc_polyglot_util_typedump_TypeDumper$sub_refs;
typedef struct _jc_polyglot_util_typedump_TypeDumper$sub_nonrefs	_jc_polyglot_util_typedump_TypeDumper$sub_nonrefs;
typedef struct _jc_polyglot_util_typedump_TypeDumper$refs	_jc_polyglot_util_typedump_TypeDumper$refs;
typedef struct _jc_polyglot_util_typedump_TypeDumper$nonrefs	_jc_polyglot_util_typedump_TypeDumper$nonrefs;
typedef struct _jc_polyglot_util_typedump_TypeDumper$object	_jc_polyglot_util_typedump_TypeDumper$object;

typedef struct _jc_polyglot_util_typedump_TypeDumper$fields_struct	_jc_polyglot_util_typedump_TypeDumper$fields_struct;
typedef const struct _jc_polyglot_util_typedump_TypeDumper$vmethods	_jc_polyglot_util_typedump_TypeDumper$vmethods;
typedef const struct _jc_polyglot_util_typedump_TypeDumper$vtable	_jc_polyglot_util_typedump_TypeDumper$vtable;
typedef const struct _jc_polyglot_util_typedump_TypeDumper$vtype	_jc_polyglot_util_typedump_TypeDumper$vtype;

// Class fields structure
struct _jc_polyglot_util_typedump_TypeDumper$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Boolean;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Class;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Double;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Float;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Integer;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Long;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Object;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Short;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24String;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Void;
	struct _jc_object	*dontExpand;
};
extern _jc_polyglot_util_typedump_TypeDumper$fields_struct _jc_polyglot_util_typedump_TypeDumper$class_fields;

// Constructors
extern void _jc_polyglot_util_typedump_TypeDumper$method$_init$f9c9831deeb00033(_jc_env *, struct _jc_polyglot_util_typedump_TypeDumper$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Long$object *);

// Virtual methods
extern void _jc_polyglot_util_typedump_TypeDumper$method$dump$30efa1ff09c02470(_jc_env *, struct _jc_polyglot_util_typedump_TypeDumper$object *, struct _jc_polyglot_util_CodeWriter$object *);
extern void _jc_polyglot_util_typedump_TypeDumper$method$dumpObject$ba0ace0c360abd4c(_jc_env *, struct _jc_polyglot_util_typedump_TypeDumper$object *, struct _jc_polyglot_util_CodeWriter$object *, struct _jc_java_lang_Object$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_typedump_TypeDumper$method_info$dump$30efa1ff09c02470;
extern _jc_method _jc_polyglot_util_typedump_TypeDumper$method_info$dumpObject$ba0ace0c360abd4c;

// Static methods
extern void _jc_polyglot_util_typedump_TypeDumper$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_polyglot_util_typedump_TypeDumper$method$class__24$57cd45dca0be1678(_jc_env *, struct _jc_java_lang_String$object *);
extern jboolean _jc_polyglot_util_typedump_TypeDumper$method$dontDump$b51c08815d17eae2(_jc_env *, struct _jc_java_lang_Class$object *);
extern struct _jc_polyglot_util_typedump_TypeDumper$object *_jc_polyglot_util_typedump_TypeDumper$method$load$6dc50d612bc9d36e(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual methods structure
struct _jc_polyglot_util_typedump_TypeDumper$vmethods {
	void	(*dump$30efa1ff09c02470)(_jc_env *, struct _jc_polyglot_util_typedump_TypeDumper$object *, struct _jc_polyglot_util_CodeWriter$object *);
	void	(*dumpObject$ba0ace0c360abd4c)(_jc_env *, struct _jc_polyglot_util_typedump_TypeDumper$object *, struct _jc_polyglot_util_CodeWriter$object *, struct _jc_java_lang_Object$object *, struct _jc_object *);
};

// Vtable
struct _jc_polyglot_util_typedump_TypeDumper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_typedump_TypeDumper$vmethods	polyglot_util_typedump_TypeDumper;
};

// Vtype
struct _jc_polyglot_util_typedump_TypeDumper$vtype {
	_jc_type			type;
	_jc_polyglot_util_typedump_TypeDumper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_typedump_TypeDumper$sub_refs {
	struct _jc_object	*theType;
	struct _jc_java_lang_String$object	*rawName;
	struct _jc_java_lang_String$object	*compilerVersion;
	struct _jc_java_util_Date$object	*timestamp;
};

// Reference instance fields (object)
struct _jc_polyglot_util_typedump_TypeDumper$refs {
    _jc_polyglot_util_typedump_TypeDumper$sub_refs	polyglot_util_typedump_TypeDumper;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_typedump_TypeDumper$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_typedump_TypeDumper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_typedump_TypeDumper$sub_nonrefs	polyglot_util_typedump_TypeDumper;
};

// Object instance structure
struct _jc_polyglot_util_typedump_TypeDumper$object {
	_jc_polyglot_util_typedump_TypeDumper$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_typedump_TypeDumper$vtype	*vtype;
	_jc_polyglot_util_typedump_TypeDumper$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_typedump_TypeDumper$vtype _jc_polyglot_util_typedump_TypeDumper$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_typedump_TypeDumper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_typedump_TypeDumper$class_object;

#endif	/* _JC_polyglot_util_typedump_TypeDumper_H_ */

==> jc-1.4.6.tar.gz: polyglot/util/typedump/TypeDumper.h <==
// class polyglot.util.typedump.TypeDumper

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ce9c276c03241184 polyglot_util_typedump_TypeDumper

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_typedump_TypeDumper_H_
#define _JC_polyglot_util_typedump_TypeDumper_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Long$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Date$object;
struct _jc_java_util_Map$object;
struct _jc_java_util_Set$object;
struct _jc_polyglot_types_Type$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_util_CodeWriter$object;
struct _jc_polyglot_util_typedump_TypeDumper$object;

// Typedefs
typedef struct _jc_polyglot_util_typedump_TypeDumper$sub_refs	_jc_polyglot_util_typedump_TypeDumper$sub_refs;
typedef struct _jc_polyglot_util_typedump_TypeDumper$sub_nonrefs	_jc_polyglot_util_typedump_TypeDumper$sub_nonrefs;
typedef struct _jc_polyglot_util_typedump_TypeDumper$refs	_jc_polyglot_util_typedump_TypeDumper$refs;
typedef struct _jc_polyglot_util_typedump_TypeDumper$nonrefs	_jc_polyglot_util_typedump_TypeDumper$nonrefs;
typedef struct _jc_polyglot_util_typedump_TypeDumper$object	_jc_polyglot_util_typedump_TypeDumper$object;

typedef struct _jc_polyglot_util_typedump_TypeDumper$fields_struct	_jc_polyglot_util_typedump_TypeDumper$fields_struct;
typedef const struct _jc_polyglot_util_typedump_TypeDumper$vmethods	_jc_polyglot_util_typedump_TypeDumper$vmethods;
typedef const struct _jc_polyglot_util_typedump_TypeDumper$vtable	_jc_polyglot_util_typedump_TypeDumper$vtable;
typedef const struct _jc_polyglot_util_typedump_TypeDumper$vtype	_jc_polyglot_util_typedump_TypeDumper$vtype;

// Class fields structure
struct _jc_polyglot_util_typedump_TypeDumper$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Boolean;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Class;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Double;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Float;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Integer;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Long;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Object;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Short;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24String;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Void;
	struct _jc_object	*dontExpand;
};
extern _jc_polyglot_util_typedump_TypeDumper$fields_struct _jc_polyglot_util_typedump_TypeDumper$class_fields;

// Constructors
extern void _jc_polyglot_util_typedump_TypeDumper$method$_init$f9c9831deeb00033(_jc_env *, struct _jc_polyglot_util_typedump_TypeDumper$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Long$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_polyglot_util_typedump_TypeDumper$method$dump$30efa1ff09c02470(_jc_env *, struct _jc_polyglot_util_typedump_TypeDumper$object *, struct _jc_polyglot_util_CodeWriter$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_util_typedump_TypeDumper$method$dumpObject$ba0ace0c360abd4c(_jc_env *, struct _jc_polyglot_util_typedump_TypeDumper$object *, struct _jc_polyglot_util_CodeWriter$object *, struct _jc_java_lang_Object$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_typedump_TypeDumper$method_info$dump$30efa1ff09c02470;
extern _jc_method _jc_polyglot_util_typedump_TypeDumper$method_info$dumpObject$ba0ace0c360abd4c;

// Static methods
extern void _jc_polyglot_util_typedump_TypeDumper$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_polyglot_util_typedump_TypeDumper$method$class__24$57cd45dca0be1678(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern jboolean _jc_polyglot_util_typedump_TypeDumper$method$dontDump$b51c08815d17eae2(_jc_env *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_util_typedump_TypeDumper$object *_jc_polyglot_util_typedump_TypeDumper$method$load$6dc50d612bc9d36e(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_util_typedump_TypeDumper$vmethods {
	void	(*dump$30efa1ff09c02470)(_jc_env *, struct _jc_polyglot_util_typedump_TypeDumper$object *, struct _jc_polyglot_util_CodeWriter$object *) _JC_JCNI_ATTR;
	void	(*dumpObject$ba0ace0c360abd4c)(_jc_env *, struct _jc_polyglot_util_typedump_TypeDumper$object *, struct _jc_polyglot_util_CodeWriter$object *, struct _jc_java_lang_Object$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_util_typedump_TypeDumper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_typedump_TypeDumper$vmethods	polyglot_util_typedump_TypeDumper;
};

// Vtype
struct _jc_polyglot_util_typedump_TypeDumper$vtype {
	_jc_type			type;
	_jc_polyglot_util_typedump_TypeDumper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_typedump_TypeDumper$sub_refs {
	struct _jc_object	*theType;
	struct _jc_java_lang_String$object	*rawName;
	struct _jc_java_lang_String$object	*compilerVersion;
	struct _jc_java_util_Date$object	*timestamp;
};

// Reference instance fields (object)
struct _jc_polyglot_util_typedump_TypeDumper$refs {
    _jc_polyglot_util_typedump_TypeDumper$sub_refs	polyglot_util_typedump_TypeDumper;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_typedump_TypeDumper$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_typedump_TypeDumper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_typedump_TypeDumper$sub_nonrefs	polyglot_util_typedump_TypeDumper;
};

// Object instance structure
struct _jc_polyglot_util_typedump_TypeDumper$object {
	_jc_polyglot_util_typedump_TypeDumper$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_typedump_TypeDumper$vtype	*vtype;
	_jc_polyglot_util_typedump_TypeDumper$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_typedump_TypeDumper$vtype _jc_polyglot_util_typedump_TypeDumper$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_typedump_TypeDumper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_typedump_TypeDumper$class_object;

#endif	/* _JC_polyglot_util_typedump_TypeDumper_H_ */
